@@ -1,6 +1,7 @@
 import click
 from github import Github
 from github import GithubException
+from git import GitCommandError
 import git
 import os
 
@@ -45,7 +46,10 @@ def init(ctx, user_name, password,local, repo_name):
         local_repo = init_local_repo()
         local_repo.create_remote('origin', remote_repo.clone_url)
         click.echo('Push to origin...')
-        local_repo.git.push('-u', 'origin', 'master')
+        try:
+            local_repo.git.push('-u', 'origin', 'master')
+        except GitCommandError:
+            pass
         click.echo('Ready!')
 
 def init_local_repo():
