@@ -43,7 +43,10 @@ def save(ctx, message, push):
                             click.echo("- " + conflict_file)
                         click.echo('Please fix conflicts then use "gt save -p" again')    
                 else:
-                    repo.git.push()
+                    try:
+                        repo.git.push()
+                    except GitCommandError:
+                        pass
 
             else:
                 click.echo('Remote repository does not exist!')
